summaryrefslogtreecommitdiffstats
path: root/tools/code_coverage/coverage_posix.py
diff options
context:
space:
mode:
authorpshenoy@chromium.org <pshenoy@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-06-15 02:50:56 +0000
committerpshenoy@chromium.org <pshenoy@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-06-15 02:50:56 +0000
commitbb92d56ffd7ca34dd2d911cea24bd939686af405 (patch)
tree535e1ecc316b6cfdfe110fd8e47e5d52da6a6321 /tools/code_coverage/coverage_posix.py
parentc1ada5b2ac2b1c394d34032652baec424d1370be (diff)
downloadchromium_src-bb92d56ffd7ca34dd2d911cea24bd939686af405.zip
chromium_src-bb92d56ffd7ca34dd2d911cea24bd939686af405.tar.gz
chromium_src-bb92d56ffd7ca34dd2d911cea24bd939686af405.tar.bz2
Run CODE_COVERAGE test suite for pyauto tests.
Review URL: https://chromiumcodereview.appspot.com/10534171 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@142330 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'tools/code_coverage/coverage_posix.py')
-rwxr-xr-xtools/code_coverage/coverage_posix.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/tools/code_coverage/coverage_posix.py b/tools/code_coverage/coverage_posix.py
index 4f33587..553a93c 100755
--- a/tools/code_coverage/coverage_posix.py
+++ b/tools/code_coverage/coverage_posix.py
@@ -494,10 +494,10 @@ class Coverage(object):
self.test_filters[testname] = gtest_filter
# Add 'src/test/functional/pyauto_functional.py' to self.tests.
# This file with '-v --suite=CONTINUOUS' arguments runs all pyauto tests.
self.tests += [['src/chrome/test/functional/pyauto_functional.py',
'-v',
- '--suite=CONTINUOUS']]
+ '--suite=CODE_COVERAGE']]
# Medium tests?
# Not sure all of these work yet (e.g. page_cycler_tests)
@@ -494,10 +494,10 @@ class Coverage(object):
self.test_filters[testname] = gtest_filter
# Add 'src/test/functional/pyauto_functional.py' to self.tests.
- # This file with '-v --suite=CONTINUOUS' arguments runs all pyauto tests.
+ # This file with '-v --suite=CODE_COVERAGE' arguments runs all pyauto tests.
self.tests += [['src/chrome/test/functional/pyauto_functional.py',
'-v',